Purpose
-------

XIST is an extensible HTML and XML generator. XIST is also a XML parser with a
very simple and pythonesque tree API. Every XML element type corresponds to a
Python class and these Python classes provide a conversion method to transform
the XML tree (e.g. into HTML). XIST can be considered 'object oriented XSLT'.


Documentation
-------------

For documentation read the files in the ``docs/`` directory or the
`web pages`__.

__ http://www.livinglogic.de/Python/xist/

For installation instruction read ``INSTALL.rst`` or the
`installation web page`__.

__ http://www.livinglogic.de/Python/xist/Installation.html

For a history of XIST and a list of new features in this version,
read ``NEWS.rst`` or the `history web page`__.

__ http://www.livinglogic.de/Python/xist/History.html

For the license read ``__init__.py``.


Download
--------

XIST is available via ftp_, http_, from the cheeseshop_ or as a
`debian package`_.

.. _ftp: ftp://ftp.livinglogic.de/pub/livinglogic/xist/
.. _http: http://ftp.livinglogic.de/xist/
.. _cheeseshop: http://cheeseshop.python.org/pypi/ll-xist
.. _debian package: http://packages.debian.org/python-ll-xist


Mailing lists
-------------

A discussion mailing list is available. To subscribe send an email
to xist-discuss-request@livinglogic.de with "subscribe" in the body.
For more information, send an email to xist-discuss-request@livinglogic.de
with "help" in the body. Post to the list by sending an email to
xist-discuss@livinglogic.de.

A announcement mailing list is also available. To subscribe send an email
to xist-announce-request@livinglogic.de with "subscribe" in the body.
For more information, send an email to xist-announce-request@livinglogic.de
with "help" in the body.

Archives of both mailing lists is available at
http://mlarchive.livinglogic.de/


-- Walter Dörwald <walter@livinglogic.de>
